From: "Jordan Crouse" <jordan.crouse@amd.com>
To: linux-acpi@vger.kernel.org
Cc: linux-kernel@vger.kernel.org, william.morrow@amd.com
Subject: [PATCH] ACPI: Clear GPE before disabling it
Date: Tue, 8 Aug 2006 13:19:03 -0600 [thread overview]
Message-ID: <20060808191903.GA10816@cosmic.amd.com> (raw)
[-- Attachment #1: Type: text/plain, Size: 264 bytes --]
On AMD Geode BIOSen, we have problems with GPE interrupt storms. The
attached patch resolves that. This should be fine for all implementations,
though.
Jordan
--
Jordan Crouse
Senior Linux Engineer
Advanced Micro Devices, Inc.
<www.amd.com/embeddedprocessors>
[-- Attachment #2: acpi-s1-fix.patch --]
[-- Type: text/plain, Size: 1342 bytes --]
[PATCH] ACPI: Clear GPE before disabling it
From: William Morrow <william.morrow@amd.com>
On some BIOSen, the GPE bit will remain set even if it is disabled,
resulting in a interrupt storm. This patch clears the bit before
disabling it.
Signed-off-by: William Morrow <william.morrow@amd.com>
Signed-off-by: Jordan Crouse <jordan.crouse@amd.com>
---
drivers/acpi/events/evgpe.c | 14 +++++++++++++-
1 files changed, 13 insertions(+), 1 deletions(-)
diff --git a/drivers/acpi/events/evgpe.c b/drivers/acpi/events/evgpe.c
index c76c058..1f93b23 100644
--- a/drivers/acpi/events/evgpe.c
+++ b/drivers/acpi/events/evgpe.c
@@ -677,10 +677,22 @@ acpi_ev_gpe_dispatch(struct acpi_gpe_eve
case ACPI_GPE_DISPATCH_METHOD:
/*
* Disable GPE, so it doesn't keep firing before the method has a
* chance to run.
*/
+ status = acpi_hw_clear_gpe(gpe_event_info);
+ if (ACPI_FAILURE(status)) {
+ ACPI_EXCEPTION((AE_INFO, status,
+ "Unable to clear GPE[%2X]",
+ gpe_number));
+ return_UINT32(ACPI_INTERRUPT_NOT_HANDLED);
+ }
+ /*
+ * Disable GPE, so it doesn't keep happen again.
+ */
+
status = acpi_ev_disable_gpe(gpe_event_info);
+
if (ACPI_FAILURE(status)) {
ACPI_EXCEPTION((AE_INFO, status,
"Unable to disable GPE[%2X]",
reply other threads:[~2006-08-08 19:17 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20060808191903.GA10816@cosmic.amd.com \
--to=jordan.crouse@amd.com \
--cc=linux-acpi@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=william.morrow@amd.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -677,10 +677,22 @@ acpi_ev_gpe_dispatch(struct acpi_gpe_eve
case ACPI_GPE_DISPATCH_METHOD:
/*
- * Disable GPE, so it doesn't keep firing before the method has a
+ * Clear GPE, so it doesn't keep firing before the method has a
* chance to run.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox